
'filesysobjects' - package
###########################

.. toctree::
   :maxdepth: 4

.. automodule:: filesysobjects.FileSysObjects

**Sources**

* `filesysobjects.FileSysObjects [source] <_modules/filesysobjects/FileSysObjects.html#>`_

* `filesysobjects.NetFiles [source] <_modules/filesysobjects/NetFiles.html#>`_


.. include:: filesysobjects.rst
.. include:: netfiles.rst

